@@ -1,10 +1,10 @@
 # @package      hubzero-submit-common
 # @file         CommandParser.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -33,8 +33,9 @@ import math
 import csv
 import copy
 import fnmatch
+import logging
 
-from hubzero.submit.LogMessage    import logID as log
+from hubzero.submit.LogMessage    import getLogIDMessage as getLogMessage
 from hubzero.submit.CommentedFile import CommentedFile
 
 class CommandParser:
@@ -401,6 +402,7 @@ class CommandParser:
 
    def __init__(self,
                 doubleDashTerminator=False):
+      self.logger               = logging.getLogger(__name__)
       self.commandOptions       = None
       self.commandArguments     = []
       self.sweepParameters      = {}
@@ -443,15 +445,16 @@ submit -d input.csv sim.exe @:indeck
 \n\n
 \tTakes parameters from the data file input.csv, which must be in comma-separated value format.
 The first line of this file may contain a series of @@param names for each of the columns.
+Whitespace is significant for all values entered in the csv file.
 If it doesn't, then the columns are assumed to be called @@1, @@2, @@3, etc.
 Each of the remaining lines represents a set of parameter values for one job; if there are 100 such lines, there will be 100 jobs.
 For example, the file input.csv might look like this:
 \n\n
-\t\t@@vth, @@cap\n
-\t\t1.1, 1pf\n
-\t\t2.2, 1pf\n
-\t\t1.1, 10pf\n
-\t\t2.2, 10pf
+\t\t@@vth,@@cap\n
+\t\t1.1,1pf\n
+\t\t2.2,1pf\n
+\t\t1.1,10pf\n
+\t\t2.2,10pf
 \n\n
 \tParameters are substituted as before into template files such as @:indeck.
 \n\n
@@ -591,7 +594,11 @@ submit -p @@file=globnat:indeck* sim.exe @@file
       self.parser.add_option("-M","--metrics",action="store_true",dest="metrics", \
                                               help="Report resource usage on exit")
       self.parser.set_defaults(detach=False)
+      self.parser.add_option("--detach",action="store_true",dest="detach", \
+                                        help=SUPPRESS_HELP)
       self.parser.set_defaults(attachId=0L)
+      self.parser.add_option("--attach",action="store",type="long",dest="attachId", \
+                                        help=SUPPRESS_HELP)
       self.parser.set_defaults(waitSwitch=False)
       self.parser.add_option("-W","--wait",action="store_true",dest="waitSwitch", \
                                            help="Wait for reduced job load before submission")
@@ -610,9 +617,9 @@ submit -p @@file=globnat:indeck* sim.exe @@file
       self.parser.set_defaults(disableStateCheck=False)
       self.parser.add_option("--disableStateCheck",action="store_true",dest="disableStateCheck", \
                                                    help=SUPPRESS_HELP)
-      self.parser.set_defaults(disableProbeCheck=True)
-#     self.parser.add_option("--disableProbeCheck",action="store_true",dest="disableProbeCheck", \
-#                                                  help=SUPPRESS_HELP)
+      self.parser.set_defaults(disableProbeCheck=False)
+      self.parser.add_option("--disableProbeCheck",action="store_true",dest="disableProbeCheck", \
+                                                   help=SUPPRESS_HELP)
       self.parser.add_option("--userLogPath",action="store",type="string",dest="userLogPath", \
                                              help=SUPPRESS_HELP)
       self.parser.add_option("--userJobidPath",action="store",type="string",dest="userJobidPath", \
@@ -761,77 +768,77 @@ submit -p @@file=globnat:indeck* sim.exe @@file
       validArguments = True
       if self.getOption('localExecution') and self.getOption('destinations'):
          errorMessage = "Local execution cannot be combined with remote destinations"
-         log(errorMessage)
+         self.logger.log(logging.ERROR,getLogMessage(errorMessage))
          validArguments = False
       if self.getOption('localExecution') and self.getOption('detach'):
          errorMessage = "Local execution cannot run detached"
-         log(errorMessage)
+         self.logger.log(logging.ERROR,getLogMessage(errorMessage))
          validArguments = False
       if self.getOption('statusIds') != None and self.getOption('detach'):
          errorMessage = "Status reporting cannot run detached"
-         log(errorMessage)
+         self.logger.log(logging.ERROR,getLogMessage(errorMessage))
          validArguments = False
       if self.getOption('killIds') != None and self.getOption('detach'):
          errorMessage = "Run termination cannot run detached"
-         log(errorMessage)
+         self.logger.log(logging.ERROR,getLogMessage(errorMessage))
          validArguments = False
       if self.getOption('statusIds') != None and self.getOption('attachId'):
          errorMessage = "Status reporting cannot be combined with attach"
-         log(errorMessage)
+         self.logger.log(logging.ERROR,getLogMessage(errorMessage))
          validArguments = False
       if self.getOption('killIds') != None and self.getOption('attachId'):
          errorMessage = "Run termination cannot be combined with attach"
-         log(errorMessage)
+         self.logger.log(logging.ERROR,getLogMessage(errorMessage))
          validArguments = False
       if self.getOption('help') or self.getOption('helpTools') or \
          self.getOption('helpVenues') or self.getOption('helpManagers'):
          if self.getOption('detach'):
             errorMessage = "Help cannot be combined with the detach option"
-            log(errorMessage)
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             validArguments = False
          if self.getOption('attachId'):
             errorMessage = "Help cannot be combined with the attach option"
-            log(errorMessage)
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             validArguments = False
       if self.getOption('version') or self.getOption('versionClient') or \
          self.getOption('versionServer') or self.getOption('versionDistributor'):
          if self.getOption('detach'):
             errorMessage = "version cannot be combined with the detach option"
-            log(errorMessage)
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             validArguments = False
          if self.getOption('attachId'):
             errorMessage = "version cannot be combined with the attach option"
-            log(errorMessage)
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             validArguments = False
 
       if self.getOption('runName'):
          runName = self.getOption('runName')
          if not runName.isalnum():
             errorMessage = "runName contains non-alphanumeric characters"
-            log(errorMessage)
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             validArguments = False
 
       if   self.getOption('statusIds') != None and self.getOption('killIds') != None:
          errorMessage = "Status reporting cannot be combined with run termination"
-         log(errorMessage)
+         self.logger.log(logging.ERROR,getLogMessage(errorMessage))
          validArguments = False
       elif len(self.commandArguments) > 0:
          if self.getOption('statusIds') != None:
             errorMessage = "Status reporting cannot be combined with run submission"
-            log(errorMessage)
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             validArguments = False
          if self.getOption('killIds') != None:
             errorMessage = "Run termination cannot be combined with run submission"
-            log(errorMessage)
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             validArguments = False
          if self.getOption('help') or self.getOption('helpTools') or \
             self.getOption('helpVenues') or self.getOption('helpManagers'):
             errorMessage = "Help cannot be combined with run submission"
-            log(errorMessage)
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             validArguments = False
          if self.getOption('attachId') != 0L:
             errorMessage = "Run attachment cannot be combined with run submission"
-            log(errorMessage)
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             validArguments = False
       
       return(validArguments)
@@ -1000,7 +1007,7 @@ submit -p @@file=globnat:indeck* sim.exe @@file
                      self.sweepParameters[name] = self.parseParameter(parameter,separator)
                   else:
                      errorMessage = "Parameter @@%s defined more than once" % (name)
-                     log(errorMessage)
+                     self.logger.log(logging.ERROR,getLogMessage(errorMessage))
                      exitCode = 1
                elif os.path.isfile(sweepParameter):
                   sep = ','
@@ -1020,11 +1027,11 @@ submit -p @@file=globnat:indeck* sim.exe @@file
                                        self.sweepParameters[name] = self.parseParameter(parameter,sep)
                                     else:
                                        errorMessage = "Parameter @@%s defined more than once" % (name)
-                                       log(errorMessage)
+                                       self.logger.log(logging.ERROR,getLogMessage(errorMessage))
                                        exitCode = 1
                                  else:
                                     errorMessage = "Bad parameter definition \"%s\" -- should be @@NAME=expr" % (sweepParameter)
-                                    log(errorMessage)
+                                    self.logger.log(logging.ERROR,getLogMessage(errorMessage))
                                     exitCode = 1
                            elif separatorPattern.match(record):
                               sep = separatorPattern.match(record).group(1)
@@ -1033,7 +1040,7 @@ submit -p @@file=globnat:indeck* sim.exe @@file
                      fpParams.close()
                else:
                   errorMessage = "Bad parameter definition \"%s\" -- should be @@NAME=expr or a file" % (sweepParameter)
-                  log(errorMessage)
+                  self.logger.log(logging.ERROR,getLogMessage(errorMessage))
                   exitCode = 1
 
       return(exitCode)
@@ -1069,7 +1076,7 @@ submit -p @@file=globnat:indeck* sim.exe @@file
                      self.csvDataHasHeader  = True
                   else:
                      errorMessage = "Parameter data file %s: header not properly specified" % (csvDataFile)
-                     log(errorMessage)
+                     self.logger.log(logging.ERROR,getLogMessage(errorMessage))
                      exitCode = 1
 
                   for row in csvReader:
@@ -1077,13 +1084,13 @@ submit -p @@file=globnat:indeck* sim.exe @@file
 
                except csv.Error,e:
                   errorMessage = "Error in parameter data file %s, line %d: %s" % (csvDataFile,csvReader.line_num,e)
-                  log(errorMessage)
+                  self.logger.log(logging.ERROR,getLogMessage(errorMessage))
                   exitCode = 1
 
                fpCSVData.close()
          else:
             errorMessage = "%s is not a file" % (csvDataFile)
-            log(errorMessage)
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             exitCode = 1
 
       return(exitCode)
@@ -1103,7 +1110,7 @@ submit -p @@file=globnat:indeck* sim.exe @@file
             fpCSV.close()
          except csv.Error,e:
             errorMessage = "Error in parameter data file %s, line %d: %s" % (csvDataFile,csvReader.line_num,e)
-            log(errorMessage)
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
 
 
    def __getCSVDataCombinations(self):
@@ -1262,6 +1269,6 @@ submit -p @@file=globnat:indeck* sim.exe @@file
             fpCSV.close()
          except csv.Error,e:
             errorMessage = "Error in parameter data file %s, line %d: %s" % (csvPath,csvReader.line_num,e)
-            log(errorMessage)
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
 
 
