@@ -1,10 +1,10 @@
 # @package      hubzero-submit-common
 # @file         LogMessage.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -28,6 +28,7 @@
 import sys
 import os
 import time
+import logging
 
 LOGMESSAGEFILE = sys.stdout
 LOGJOBID       = 0
@@ -64,7 +65,8 @@ def logSetMessageFile(fpMessageFile):
       LOGMESSAGEFILE = fpMessageFile
 
 
-def log(message):
+
+def __logMessage(message):
    global LOGMESSAGEFILE
 
    if LOGMESSAGEFILE and message != "":
@@ -72,12 +74,26 @@ def log(message):
       LOGMESSAGEFILE.flush()
 
 
-def logPID(message):
-   global LOGMESSAGEFILE
+def getLogMessage(message):
+   logMessage = message
 
-   if LOGMESSAGEFILE and message != "":
-      LOGMESSAGEFILE.write("[%s] (%d) %s\n" % (time.ctime(),os.getpid(),message))
-      LOGMESSAGEFILE.flush()
+   return(logMessage)
+
+
+def log(message):
+   __logMessage(getLogMessage(message))
+
+
+def getLogPIDMessage(message):
+   logMessage = ""
+   if message != "":
+      logMessage = "(%d) %s" % (os.getpid(),message)
+
+   return(logMessage)
+
+
+def logPID(message):
+   __logMessage(getLogPIDMessage(message))
 
 
 def logSetJobId(jobId):
@@ -86,23 +102,35 @@ def logSetJobId(jobId):
    LOGJOBID = jobId
 
 
-def logJobId(message):
-   global LOGMESSAGEFILE
+def getLogJobIdMessage(message):
    global LOGJOBID
 
-   if LOGMESSAGEFILE and message != "":
-      LOGMESSAGEFILE.write("[%s] %d: %s\n" % (time.ctime(),LOGJOBID,message))
-      LOGMESSAGEFILE.flush()
+   logMessage = ""
+   if message != "":
+      logMessage = "%d: %s" % (LOGJOBID,message)
+
+   return(logMessage)
+
+
+def logJobId(message):
+   __logMessage(getLogJobIdMessage(message))
+
+
+def getLogIDMessage(message):
+   global LOGJOBID
+
+   logMessage = ""
+   if message != "":
+      if LOGJOBID > 0:
+         logMessage = getLogJobIdMessage(message)
+      else:
+         logMessage = getLogPIDMessage(message)
+
+   return(logMessage)
 
 
 def logID(message):
-   global LOGJOBID
-
-   if message != "":
-      if LOGJOBID > 0:
-         logJobId(message)
-      else:
-         logPID(message)
+   __logMessage(getLogIDMessage(message))
 
 
 def isLogMessageFileStdout():
