@@ -1,10 +1,10 @@
 # @package      hubzero-submit-common
 # @file         MessageCore.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -31,9 +31,10 @@ import os
 import socket
 import time
 import traceback
-from errno import EAGAIN,EWOULDBLOCK
+import logging
+from errno import EAGAIN,EWOULDBLOCK,EPIPE,ECONNRESET
 
-from hubzero.submit.LogMessage import logID as log
+from hubzero.submit.LogMessage import getLogIDMessage as getLogMessage
 
 class MessageCore:
    def __init__(self,
@@ -51,6 +52,7 @@ class MessageCore:
                 listenerPort=0,
                 listenerFile="",
                 repeatDelay=5):
+      self.logger       = logging.getLogger(__name__)
       self.protocol     = protocol
       self.family       = None
       self.bindHost     = bindHost
@@ -99,9 +101,11 @@ class MessageCore:
          if not bound:
             self.bindSocket = None
             if   self.family == socket.AF_INET:
-               log("Can't bind to port %d: %s %s" % (bindPort,sys.exc_info()[0],sys.exc_info()[1]))
+               message = "Can't bind to port %d: %s %s" % (bindPort,sys.exc_info()[0],sys.exc_info()[1])
+               self.logger.log(logging.ERROR,getLogMessage(message))
             elif self.family == socket.AF_UNIX:
-               log("Can't bind to file %s: %s %s" % (bindFile,sys.exc_info()[0],sys.exc_info()[1]))
+               message = "Can't bind to file %s: %s %s" % (bindFile,sys.exc_info()[0],sys.exc_info()[1])
+               self.logger.log(logging.ERROR,getLogMessage(message))
       else:
          if   listenerPort > 0:
             self.family = socket.AF_INET
@@ -186,7 +190,7 @@ class MessageCore:
       try:
          channel,details = self.bindSocket.accept()
       except socket.error,err:
-         log(traceback.format_exc())
+         self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
          if err[0] in [EAGAIN,EWOULDBLOCK]:
             channel = None
          else:
@@ -202,15 +206,15 @@ class MessageCore:
                except Exception:
                   pass
             if logConnection:
-               log("====================================================")
+               self.logger.log(logging.INFO,getLogMessage("===================================================="))
                if determineDetails:
-                  log("Connection to %s from %s %s" % (self.bindLabel,details,remoteHost))
+                  self.logger.log(logging.INFO,getLogMessage("Connection to %s from %s %s" % (self.bindLabel,details,remoteHost)))
                else:
-                  log("Connection to %s from %s" % (self.bindLabel,details))
+                  self.logger.log(logging.INFO,getLogMessage("Connection to %s from %s" % (self.bindLabel,details)))
          elif self.family == socket.AF_UNIX:
             if logConnection:
-               log("====================================================")
-               log("Connection to %s" % (self.bindLabel))
+               self.logger.log(logging.INFO,getLogMessage("===================================================="))
+               self.logger.log(logging.INFO,getLogMessage("Connection to %s" % (self.bindLabel)))
 
       if determineDetails:
          return(channel,remoteIP,remotePort,remoteHost)
@@ -233,16 +237,16 @@ class MessageCore:
          raise
       except Exception,err:
          if err.args[0] == 111:
-            log("openListenerChannel: %s" % (err.args[1]))
+            self.logger.log(logging.ERROR,getLogMessage("openListenerChannel: %s" % (err.args[1])))
          else:
             if recordTraceback:
-               log(traceback.format_exc())
+               self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
          if listenerChannel:
             listenerChannel.close()
          listenerChannel = None
       except:
          if recordTraceback:
-            log(traceback.format_exc())
+            self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
          if listenerChannel:
             listenerChannel.close()
          listenerChannel = None
@@ -264,8 +268,19 @@ class MessageCore:
       while True:
          try:
             messageChunk = channel.recv(bufferSize)
-         except socket.error:
+         except socket.error,err:
             # Happens on non-blocking TCP socket when there's nothing to read
+            if isinstance(err.args,tuple):
+               if   err.args[0] in [ECONNRESET]:
+                  # Connection reset by peer
+                  if not message:
+                     message = None
+               elif not err.args[0] in [EAGAIN,EWOULDBLOCK]:
+                  self.logger.log(logging.ERROR,getLogMessage("Unexpected error in receiveNonBlockingMessage()"))
+                  self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
+            else:
+               self.logger.log(logging.ERROR,getLogMessage("Unexpected error in receiveNonBlockingMessage()"))
+               self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
             break
          except (SSL.WantReadError, SSL.WantWriteError, SSL.WantX509LookupError):
             # Happens on non-blocking TCP/SSL socket when there's nothing to read
@@ -273,10 +288,12 @@ class MessageCore:
          except SSL.SysCallError, (errnum,errstr):
             if errnum == -1:
                # Unexpected EOF
+               if not message:
+                  message = None
                break
          except:
-            log("Unexpected error in receiveNonBlockingMessage() " + message)
-            log(traceback.format_exc())
+            self.logger.log(logging.ERROR,getLogMessage("Unexpected error in receiveNonBlockingMessage() " + message))
+            self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
             if not message:
                message = None
             break
@@ -305,13 +322,13 @@ class MessageCore:
             bytesRemaining -= len(messageChunk)
             if messageChunk == "":
                if message != "":
-                  log("socket connection broken in receiveBlockingMessage()")
+                  self.logger.log(logging.ERROR,getLogMessage("socket connection broken in receiveBlockingMessage()"))
                else:
                   message = None
                break
       except:
-         log("Unexpected error in receiveBlockingMessage() " + message)
-         log(traceback.format_exc())
+         self.logger.log(logging.ERROR,getLogMessage("Unexpected error in receiveBlockingMessage() " + message))
+         self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
          if message == "":
             message = None
 
@@ -337,13 +354,20 @@ class MessageCore:
       try:
          transmittedLength = channel.send(message)
          if transmittedLength == 0:
-            log("socket connection broken in sendNonBlockingMessage()")
+            self.logger.log(logging.ERROR,getLogMessage("socket connection broken in sendNonBlockingMessage()"))
             transmittedLength = -1
       except (SSL.WantReadError, SSL.WantWriteError, SSL.WantX509LookupError):
          transmittedLength = 0
-      except:
-         log("Unexpected error in sendNonBlockingMessage(%s)" % (message))
-         log(traceback.format_exc())
+      except Exception,err:
+         if isinstance(err.args,tuple):
+            if not err[0] in [EPIPE]:
+               self.logger.log(logging.ERROR,getLogMessage("Unexpected error in sendNonBlockingMessage(%s)" % (message[0:20])))
+               self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
+            else:
+               self.logger.log(logging.ERROR,getLogMessage("sendNonBlockingMessage: Broken pipe"))
+         else:
+            self.logger.log(logging.ERROR,getLogMessage("Unexpected error in sendNonBlockingMessage(%s)" % (message[0:20])))
+            self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
          transmittedLength = -1
 
       return(transmittedLength)
@@ -361,7 +385,7 @@ class MessageCore:
                transmittedLength = channel.send(fixedBufferMessage[fixedBufferSize-bytesRemaining:])
                bytesRemaining -= transmittedLength
                if transmittedLength == 0:
-                  log("socket connection broken in sendBlockingMessage()")
+                  self.logger.log(logging.ERROR,getLogMessage("socket connection broken in sendBlockingMessage()"))
                   transmittedLength = -1
                   break
          else:
@@ -370,16 +394,23 @@ class MessageCore:
                transmittedLength = channel.send(message[len(message)-bytesRemaining:])
                bytesRemaining -= transmittedLength
                if transmittedLength == 0:
-                  log("socket connection broken in sendBlockingMessage()")
+                  self.logger.log(logging.ERROR,getLogMessage("socket connection broken in sendBlockingMessage()"))
                   transmittedLength = -1
                   break
       except SSL.Error, err:
          (lib,function,reason) = err.args[0][0]
-         log("sendBlockingMessage: SSL error, %s" % (reason))
+         self.logger.log(logging.ERROR,getLogMessage("sendBlockingMessage: SSL error, %s" % (reason)))
          transmittedLength = -1
-      except:
-         log("Unexpected error in sendBlockingMessage(%s)" % (message))
-         log(traceback.format_exc())
+      except Exception,err:
+         if isinstance(err.args,tuple):
+            if not err[0] in [EPIPE]:
+               self.logger.log(logging.ERROR,getLogMessage("Unexpected error in sendBlockingMessage(%s)" % (message[0:20])))
+               self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
+            else:
+               self.logger.log(logging.ERROR,getLogMessage("sendBlockingMessage: Broken pipe"))
+         else:
+            self.logger.log(logging.ERROR,getLogMessage("Unexpected error in sendBlockingMessage(%s)" % (message[0:20])))
+            self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
          transmittedLength = -1
 
       return(transmittedLength)
@@ -426,7 +457,7 @@ class MessageCore:
                   posted = True
          except:
             if recordTraceback:
-               log(traceback.format_exc())
+               self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
 
          if messageResponseSocket:
             messageResponseSocket.close()
@@ -466,7 +497,7 @@ class MessageCore:
                      posted = True
          except:
             if recordTraceback:
-               log(traceback.format_exc())
+               self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
 
          if messageResponseSocket:
             messageResponseSocket.close()
@@ -506,7 +537,7 @@ class MessageCore:
                      posted = True
          except:
             if recordTraceback:
-               log(traceback.format_exc())
+               self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
 
          if messageResponseSocket:
             messageResponseSocket.close()
