@@ -1,10 +1,10 @@
 # @package      hubzero-submit-common
 # @file         RemoteJobMonitor.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -30,11 +30,12 @@ import time
 import traceback
 import csv
 import os
+import logging
 from errno import EPIPE
 
-from hubzero.submit.LogMessage  import logID as log
+from hubzero.submit.LogMessage  import getLogIDMessage as getLogMessage
 from hubzero.submit.MessageCore import MessageCore
-from hubzero.submit.JobOutput   import *
+from hubzero.submit.JobOutput   import JobOutput
 
 class RemoteJobMonitor(MessageCore):
    def __init__(self,
@@ -43,6 +44,9 @@ class RemoteJobMonitor(MessageCore):
                 repeatDelay=5,
                 fixedBufferSize=128):
       MessageCore.__init__(self,listenerHost=host,listenerPort=port,repeatDelay=repeatDelay)
+
+      self.logger          = logging.getLogger(__name__)
+      self.jobOutput       = JobOutput()
       self.fixedBufferSize = fixedBufferSize
       self.enteredCommand  = None
       self.startDate       = None
@@ -106,14 +110,24 @@ class RemoteJobMonitor(MessageCore):
       self.jobStatusReportOrders['finished']   = 2
 
 
-   @staticmethod
-   def __writeToStdout(message):
+   def __writeToStdout(self,
+                       message):
       try:
          sys.stdout.write(message)
          sys.stdout.flush()
       except IOError,err:
          if not err[0] in [EPIPE]:
-            log("Can't write to stdout: %s" % (message))
+            self.logger.log(logging.ERROR,getLogMessage("Can't write to stdout: %s" % (message)))
+
+
+   def __writeToStderr(self,
+                       message):
+      try:
+         sys.stderr.write(message)
+         sys.stderr.flush()
+      except IOError,err:
+         if not err[0] in [EPIPE]:
+            self.logger.log(logging.ERROR,getLogMessage("Can't write to stderr: %s" % (message)))
 
 
    def postJobSubmission(self,
@@ -136,7 +150,7 @@ class RemoteJobMonitor(MessageCore):
                                                   self.fixedBufferSize,
                                                   self.fixedBufferSize)
 
-      log("confirmation: S(%d):%s" % (nTry,response.strip()))
+      self.logger.log(logging.WARNING,getLogMessage("confirmation: S(%d):%s" % (nTry,response.strip())))
 
 
    def postPegasusWorkflowSubmission(self,
@@ -160,7 +174,7 @@ class RemoteJobMonitor(MessageCore):
                                                   self.fixedBufferSize,
                                                   self.fixedBufferSize)
 
-      log("confirmation: S(%d):%s" % (nTry,response.strip()))
+      self.logger.log(logging.WARNING,getLogMessage("confirmation: S(%d):%s" % (nTry,response.strip())))
 
 
    def queryRemoteJobStatus(self,
@@ -172,7 +186,7 @@ class RemoteJobMonitor(MessageCore):
                                                   self.fixedBufferSize)
 
       if nTry > 1:
-         log("confirmation: Q(%d):%s" % (nTry,response.strip()))
+         self.logger.log(logging.WARNING,getLogMessage("confirmation: Q(%d):%s" % (nTry,response.strip())))
 
       jobStatus,jobStage = response.strip().split()
       if ';' in jobStage:
@@ -196,7 +210,7 @@ class RemoteJobMonitor(MessageCore):
       response = response.split(':')
 
       if nTry > 1:
-         log("confirmation: W(%d):%s" % (nTry,response[0].strip()))
+         self.logger.log(logging.WARNING,getLogMessage("confirmation: W(%d):%s" % (nTry,response[0].strip())))
 
       dagStatus,dagStage = response[0].strip().split()
       if ';' in dagStage:
@@ -225,7 +239,7 @@ class RemoteJobMonitor(MessageCore):
                                                   self.fixedBufferSize,
                                                   self.fixedBufferSize)
 
-      log("confirmation: T(%d):%s" % (nTry,response.strip()))
+      self.logger.log(logging.WARNING,getLogMessage("confirmation: T(%d):%s" % (nTry,response.strip())))
 
 
    def queryRemoteActiveJobStatus(self,
@@ -237,7 +251,7 @@ class RemoteJobMonitor(MessageCore):
                                                                         self.fixedBufferSize)
 
       if nTry > 1:
-         log("confirmation: R(%d):%s" % (nTry,lastReportTime.strip()))
+         self.logger.log(logging.WARNING,getLogMessage("confirmation: R(%d):%s" % (nTry,lastReportTime.strip())))
 
       return(float(lastReportTime),report)
 
@@ -250,7 +264,7 @@ class RemoteJobMonitor(MessageCore):
                                                                     self.fixedBufferSize)
 
       if nTry > 1:
-         log("confirmation: A(%d):%s" % (nTry,reportTime.strip()))
+         self.logger.log(logging.WARNING,getLogMessage("confirmation: A(%d):%s" % (nTry,reportTime.strip())))
 
       reportedActivities = {}
       if len(report) > 0:
@@ -270,7 +284,7 @@ class RemoteJobMonitor(MessageCore):
                                                                     self.fixedBufferSize)
 
       if nTry > 1:
-         log("confirmation: U(%d):%s" % (nTry,reportTime.strip()))
+         self.logger.log(logging.WARNING,getLogMessage("confirmation: U(%d):%s" % (nTry,reportTime.strip())))
 
       reportedJobs = {}
       if len(report) > 0:
@@ -301,7 +315,7 @@ class RemoteJobMonitor(MessageCore):
                                                                     self.fixedBufferSize)
 
       if nTry > 1:
-         log("confirmation: P(%d):%s" % (nTry,reportTime.strip()))
+         self.logger.log(logging.WARNING,getLogMessage("confirmation: P(%d):%s" % (nTry,reportTime.strip())))
 
       activeJobPid = None
       if len(report) > 0:
@@ -315,7 +329,7 @@ class RemoteJobMonitor(MessageCore):
       try:
          jobStatusMessage = self.jobStatus[jobStatus]['message']
       except:
-         log(traceback.format_exc())
+         self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
          jobStatusMessage = 'Unknown Status(%s)' % (jobStatus)
 
       return(jobStatusMessage)
@@ -333,7 +347,7 @@ class RemoteJobMonitor(MessageCore):
       try:
          jobStatusState = self.jobStatus[jobStatus]['state']
       except:
-         log(traceback.format_exc())
+         self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
          jobStatusState = 'Unknown State(%s)' % (jobStatus)
 
       return(jobStatusState)
@@ -383,11 +397,11 @@ class RemoteJobMonitor(MessageCore):
                   waitForJobsInfo[instance]['recentJobSite'] = currentJobSite
                jobStatusMessage = self.__getJobStatusMessage(currentJobStatus)
                if currentJobSite == "" or currentJobSite == '?':
-                  log("status:%s %s" % (currentJobStage,currentJobStatus))
+                  self.logger.log(logging.INFO,getLogMessage("status:%s %s" % (currentJobStage,currentJobStatus)))
                   self.__writeToStdout("(%s) %s %s %s\n" % (remoteJobId,currentJobStage,jobStatusMessage, \
                                                                                         time.ctime()))
                else:
-                  log("status:%s %s %s" % (currentJobStage,currentJobStatus,currentJobSite))
+                  self.logger.log(logging.INFO,getLogMessage("status:%s %s %s" % (currentJobStage,currentJobStatus,currentJobSite)))
                   self.__writeToStdout("(%s) %s %s at %s %s\n" % (remoteJobId,currentJobStage,jobStatusMessage, \
                                                                                               currentJobSite,time.ctime()))
             else:
@@ -435,11 +449,13 @@ class RemoteJobMonitor(MessageCore):
                      currentJobSite != previousJobSite:
                      jobStatusMessage = self.__getJobStatusMessage(currentJobStatus)
                      if currentJobSite == "" or currentJobSite == '?':
-                        log("status:%s %s" % (currentJobStage,currentJobStatus))
+                        message = "status:%s %s" % (currentJobStage,currentJobStatus)
+                        self.logger.log(logging.INFO,getLogMessage(message))
                         self.__writeToStdout("(%s) %s %s %s\n" % (remoteJobId,currentJobStage,jobStatusMessage, \
                                                                                               time.ctime()))
                      else:
-                        log("status:%s %s %s" % (currentJobStage,currentJobStatus,currentJobSite))
+                        message = "status:%s %s %s" % (currentJobStage,currentJobStatus,currentJobSite)
+                        self.logger.log(logging.INFO,getLogMessage(message))
                         self.__writeToStdout("(%s) %s %s at %s %s\n" % (remoteJobId,currentJobStage,jobStatusMessage, \
                                                                                                     currentJobSite,time.ctime()))
                      waitForJobsInfo[instance]['recentJobStatus'] = currentJobStatus
@@ -463,8 +479,9 @@ class RemoteJobMonitor(MessageCore):
                                                                                                        currentJobSite,time.ctime()))
                         timeLastReported = delayTime
 
-      log("waitForBatchJobs: nCompleteRemoteJobIndexes = %d, nIncompleteJobs = %d, abortGlobal = %s" % \
-                    (len(completeRemoteJobIndexes),incompleteJobs,abortGlobal['abortAttempted']))
+      message = "waitForBatchJobs: nCompleteRemoteJobIndexes = %d, nIncompleteJobs = %d, abortGlobal = %s" % \
+                    (len(completeRemoteJobIndexes),incompleteJobs,abortGlobal['abortAttempted'])
+      self.logger.log(logging.INFO,getLogMessage(message))
 
       del previousJobStatuses
       del previousJobStages
@@ -569,9 +586,9 @@ class RemoteJobMonitor(MessageCore):
                   waitForJobsInfo[instance]['recentJobSite'] = currentJobSite
                jobStatusMessage = self.__getJobStatusMessage(currentJobStatus)
                if currentJobSite == "" or currentJobSite == '?':
-                  log("status:%s %s" % (currentJobStage,currentJobStatus))
+                  self.logger.log(logging.INFO,getLogMessage("status:%s %s" % (currentJobStage,currentJobStatus)))
                else:
-                  log("status:%s %s %s" % (currentJobStage,currentJobStatus,currentJobSite))
+                  self.logger.log(logging.INFO,getLogMessage("status:%s %s %s" % (currentJobStage,currentJobStatus,currentJobSite)))
                if not isClientTTY:
                   if currentJobSite == "" or currentJobSite == '?':
                      self.__writeToStdout("(%s) %s %s %s\n" % (remoteJobId,currentJobStage,jobStatusMessage, \
@@ -626,9 +643,11 @@ class RemoteJobMonitor(MessageCore):
                      currentJobSite != previousJobSite:
                      jobStatusMessage = self.__getJobStatusMessage(currentJobStatus)
                      if currentJobSite == "" or currentJobSite == '?':
-                        log("status:%s %s" % (currentJobStage,currentJobStatus))
+                        message = "status:%s %s" % (currentJobStage,currentJobStatus)
+                        self.logger.log(logging.INFO,getLogMessage(message))
                      else:
-                        log("status:%s %s %s" % (currentJobStage,currentJobStatus,currentJobSite))
+                        message = "status:%s %s %s" % (currentJobStage,currentJobStatus,currentJobSite)
+                        self.logger.log(logging.INFO,getLogMessage(message))
                      if not isClientTTY:
                         if currentJobSite == "" or currentJobSite == '?':
                            self.__writeToStdout("(%s) %s %s %s\n" % (remoteJobId,currentJobStage,jobStatusMessage, \
@@ -665,8 +684,9 @@ class RemoteJobMonitor(MessageCore):
 
          self.__updateSweepStatus(parameterCombinationsPath,waitForJobsInfo)
 
-      log("waitForSweepJobs: nCompleteRemoteJobIndexes = %d, nIncompleteJobs = %d, abortGlobal = %s" % \
-                    (len(completeRemoteJobIndexes),incompleteJobs,abortGlobal['abortAttempted']))
+      message = "waitForSweepJobs: nCompleteRemoteJobIndexes = %d, nIncompleteJobs = %d, abortGlobal = %s" % \
+                    (len(completeRemoteJobIndexes),incompleteJobs,abortGlobal['abortAttempted'])
+      self.logger.log(logging.INFO,getLogMessage(message))
 
       del previousJobStatuses
       del previousJobStages
@@ -766,8 +786,8 @@ class RemoteJobMonitor(MessageCore):
             knownSite             = waitForJobsInfo[executeInstance]['knownSite']
             currentJobStatus,currentJobStage,currentJobSite,wfInstances = self.queryPegasusWorkflowStatus(siteMonitorDesignator,
                                                                                                           remoteJobId,nInstances)
-            wfExitCodes = getInProgressPegasusJobExitCodes(waitForJobsInfo[executeInstance]['instanceDirectory'],
-                                                           waitForJobsInfo[executeInstance]['scratchDirectory'])
+            wfExitCodes = self.jobOutput.getInProgressPegasusJobExitCodes(waitForJobsInfo[executeInstance]['instanceDirectory'],
+                                                                          waitForJobsInfo[executeInstance]['scratchDirectory'])
             for instance in wfExitCodes:
                if wfExitCodes[instance] == 'EF':
                   if instance in wfInstances:
@@ -783,9 +803,9 @@ class RemoteJobMonitor(MessageCore):
                waitForJobsInfo[executeInstance]['recentJobSite'] = currentJobSite
             jobStatusMessage = self.__getJobStatusMessage(currentJobStatus)
             if currentJobSite == "" or currentJobSite == '?':
-               log("status:%s %s" % (currentJobStage,currentJobStatus))
+               self.logger.log(logging.INFO,getLogMessage("status:%s %s" % (currentJobStage,currentJobStatus)))
             else:
-               log("status:%s %s %s" % (currentJobStage,currentJobStatus,currentJobSite))
+               self.logger.log(logging.INFO,getLogMessage("status:%s %s %s" % (currentJobStage,currentJobStatus,currentJobSite)))
             if not isClientTTY:
                if currentJobSite == "" or currentJobSite == '?':
                   self.__writeToStdout("(%s) %s %s %s\n" % (remoteJobId,currentJobStage,jobStatusMessage, \
@@ -841,8 +861,8 @@ class RemoteJobMonitor(MessageCore):
                previousJobSite   = previousJobSites[executeInstance]
                currentJobStatus,currentJobStage,currentJobSite,wfInstances = self.queryPegasusWorkflowStatus(siteMonitorDesignator,
                                                                                                              remoteJobId,nInstances)
-               wfExitCodes = getInProgressPegasusJobExitCodes(waitForJobsInfo[executeInstance]['instanceDirectory'],
-                                                              waitForJobsInfo[executeInstance]['scratchDirectory'])
+               wfExitCodes = self.jobOutput.getInProgressPegasusJobExitCodes(waitForJobsInfo[executeInstance]['instanceDirectory'],
+                                                                             waitForJobsInfo[executeInstance]['scratchDirectory'])
                for instance in wfExitCodes:
                   if wfExitCodes[instance] == 'EF':
                      if instance in wfInstances:
@@ -863,8 +883,8 @@ class RemoteJobMonitor(MessageCore):
                         waitForJobsInfo[wfInstance]['recentJobSite'] = wfCurrentJobSite
                if instanceChangedStatus:
                   self.__updatePegasusWorkflowStatus(parameterCombinationsPath,wfInstances)
-                  getInProgressPegasusJobStdFiles(waitForJobsInfo[executeInstance]['instanceDirectory'],
-                                                  waitForJobsInfo[executeInstance]['scratchDirectory'])
+                  self.jobOutput.getInProgressPegasusJobStdFiles(waitForJobsInfo[executeInstance]['instanceDirectory'],
+                                                                 waitForJobsInfo[executeInstance]['scratchDirectory'])
                del wfInstances
 
                if currentJobSite == "" or currentJobSite == '?':
@@ -877,9 +897,11 @@ class RemoteJobMonitor(MessageCore):
                   currentJobSite != previousJobSite:
                   jobStatusMessage = self.__getJobStatusMessage(currentJobStatus)
                   if currentJobSite == "" or currentJobSite == '?':
-                     log("status:%s %s" % (currentJobStage,currentJobStatus))
+                     message = "status:%s %s" % (currentJobStage,currentJobStatus)
+                     self.logger.log(logging.INFO,getLogMessage(message))
                   else:
-                     log("status:%s %s %s" % (currentJobStage,currentJobStatus,currentJobSite))
+                     message = "status:%s %s %s" % (currentJobStage,currentJobStatus,currentJobSite)
+                     self.logger.log(logging.INFO,getLogMessage(message))
                   if not isClientTTY:
                      if currentJobSite == "" or currentJobSite == '?':
                         self.__writeToStdout("(%s) %s %s %s\n" % (remoteJobId,currentJobStage,jobStatusMessage, \
@@ -909,8 +931,9 @@ class RemoteJobMonitor(MessageCore):
                                                                                                        currentJobSite,time.ctime()))
                      timeLastReported = delayTime
 
-      log("waitForPegasusWorkflowJobs: nCompleteRemoteJobIndexes = %d, nIncompleteJobs = %d, abortGlobal = %s" % \
-                                        (len(completeRemoteJobIndexes),incompleteJobs,abortGlobal['abortAttempted']))
+      message = "waitForPegasusWorkflowJobs: nCompleteRemoteJobIndexes = %d, nIncompleteJobs = %d, abortGlobal = %s" % \
+                                        (len(completeRemoteJobIndexes),incompleteJobs,abortGlobal['abortAttempted'])
+      self.logger.log(logging.INFO,getLogMessage(message))
 
       del previousJobStatuses
       del previousJobStages
@@ -951,14 +974,15 @@ class RemoteJobMonitor(MessageCore):
                   waitForJobsInfo[instance]['recentJobSite'] = currentJobSite
                jobStatusMessage = self.__getJobStatusMessage(currentJobStatus)
                if jobStatusMessage == 'Unknown Status':
-                  log("waitForKilledBatchJobs: siteMonitor= %s,remoteJobId= %s,jobStatus= %s,jobStage= %s,jobSite= %s" % \
-                                        (siteMonitorDesignator,remoteJobId,currentJobStatus,currentJobStage,currentJobSite))
+                  message = "waitForKilledBatchJobs: siteMonitor=%s,remoteJobId=%s,jobStatus=%s,jobStage=%s,jobSite=%s" % \
+                                        (siteMonitorDesignator,remoteJobId,currentJobStatus,currentJobStage,currentJobSite)
+                  self.logger.log(logging.INFO,getLogMessage(message))
                if currentJobSite == "" or currentJobSite == '?':
-                  log("status:%s %s" % (currentJobStage,currentJobStatus))
+                  self.logger.log(logging.INFO,getLogMessage("status:%s %s" % (currentJobStage,currentJobStatus)))
                   self.__writeToStdout("(%s) %s %s %s\n" % (remoteJobId,currentJobStage,jobStatusMessage, \
                                                                                         time.ctime()))
                else:
-                  log("status:%s %s %s" % (currentJobStage,currentJobStatus,currentJobSite))
+                  self.logger.log(logging.INFO,getLogMessage("status:%s %s %s" % (currentJobStage,currentJobStatus,currentJobSite)))
                   self.__writeToStdout("(%s) %s %s at %s %s\n" % (remoteJobId,currentJobStage,jobStatusMessage, \
                                                                                               currentJobSite,time.ctime()))
             else:
@@ -1006,14 +1030,16 @@ class RemoteJobMonitor(MessageCore):
                      currentJobSite != previousJobSite:
                      jobStatusMessage = self.__getJobStatusMessage(currentJobStatus)
                      if jobStatusMessage == 'Unknown Status':
-                        log("waitForKilledBatchJobs: siteMonitor= %s,remoteJobId= %s,jobStatus= %s,jobStage= %s,jobSite= %s" % \
-                                              (siteMonitorDesignator,remoteJobId,currentJobStatus,currentJobStage,currentJobSite))
+                        message = "waitForKilledBatchJobs: siteMonitor=%s,remoteJobId=%s,jobStatus=%s,jobStage=%s,jobSite=%s" % \
+                                              (siteMonitorDesignator,remoteJobId,currentJobStatus,currentJobStage,currentJobSite)
+                        self.logger.log(logging.INFO,getLogMessage(message))
                      if currentJobSite == "" or currentJobSite == '?':
-                        log("status:%s %s" % (currentJobStage,currentJobStatus))
+                        self.logger.log(logging.INFO,getLogMessage("status:%s %s" % (currentJobStage,currentJobStatus)))
                         self.__writeToStdout("(%s) %s %s %s\n" % (remoteJobId,currentJobStage,jobStatusMessage, \
                                                                                               time.ctime()))
                      else:
-                        log("status:%s %s %s" % (currentJobStage,currentJobStatus,currentJobSite))
+                        message = "status:%s %s %s" % (currentJobStage,currentJobStatus,currentJobSite)
+                        self.logger.log(logging.INFO,getLogMessage(message))
                         self.__writeToStdout("(%s) %s %s at %s %s\n" % (remoteJobId,currentJobStage,jobStatusMessage, \
                                                                                                     currentJobSite,time.ctime()))
                      if currentJobStatus == 'D':
