@@ -1,10 +1,10 @@
 # @package      hubzero-submit-common
 # @file         TunnelsInfo.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -28,8 +28,9 @@
 import os
 import re
 import traceback
+import logging
 
-from hubzero.submit.LogMessage import logJobId as log
+from hubzero.submit.LogMessage import getLogJobIdMessage as getLogMessage
 
 class TunnelsInfo:
    def __init__(self,
@@ -37,6 +38,7 @@ class TunnelsInfo:
                 tunnelsFile,
                 localPortMinimum=2000,
                 localPortMaximum=2048):
+      self.logger           = logging.getLogger(__name__)
       self.tunnels          = {}
       self.localPortMinimum = localPortMinimum
       self.localPortMaximum = localPortMaximum
@@ -73,12 +75,13 @@ class TunnelsInfo:
                         else:
                            self.tunnels[tunnelName][key] = value
                      else:
-                        log("Undefined key = value pair %s = %s for tunnel %s" % (key,value,tunnelName))
+                        message = "Undefined key = value pair %s = %s for tunnel %s" % (key,value,tunnelName)
+                        self.logger.log(logging.WARNING,getLogMessage(message))
                else:
                   eof = True
             fpInfo.close()
       else:
-         log("Tunnels configuration file %s is missing" % (tunnelsPath))
+         self.logger.log(logging.ERROR,getLogMessage("Tunnels configuration file %s is missing" % (tunnelsPath)))
 
 
    def getSSHTunnelAddressPort(self,
@@ -90,8 +93,8 @@ class TunnelsInfo:
          if port > self.localPortMinimum and port <= self.localPortMaximum:
             address = "127.0." + self.tunnels[tunnelName]['localPortOffset'] + ".0"
       except:
-         log(traceback.format_exc())
-         log("Get sshTunnelAddressPort failed for %s" % (tunnelName))
+         self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
+         self.logger.log(logging.ERROR,getLogMessage("Get sshTunnelAddressPort failed for %s" % (tunnelName)))
       
       return(address,str(port))
 
@@ -106,8 +109,8 @@ class TunnelsInfo:
          if localPort > self.localPortMinimum and localPort <= self.localPortMaximum:
             localHost = "127.0." + self.tunnels[tunnelName]['localPortOffset'] + ".0"
       except:
-         log(traceback.format_exc())
-         log("Build sshTunnelHosts failed for %s" % (tunnelName))
+         self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
+         self.logger.log(logging.ERROR,getLogMessage("Build sshTunnelHosts failed for %s" % (tunnelName)))
       
       return(gatewayHost,localHost)
 
@@ -127,8 +130,8 @@ class TunnelsInfo:
                                " -L 127.0." + self.tunnels[tunnelName]['localPortOffset'] + ".0:" + str(localPort) + ":" + \
                                venue + ":" + venuePort + " " + gatewayUser + "@" + gatewayHost
       except:
-         log(traceback.format_exc())
-         log("Build sshTunnelCommand failed for %s" % (tunnelName))
+         self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
+         self.logger.log(logging.ERROR,getLogMessage("Build sshTunnelCommand failed for %s" % (tunnelName)))
 
       return(sshTunnelCommand)
 
@@ -145,8 +148,8 @@ class TunnelsInfo:
                                           "127.0." + self.tunnels[tunnelName]['localPortOffset'] + ".0:" + str(localPort) + ":" + \
                                           venue + ":" + venuePort
       except:
-         log(traceback.format_exc())
-         log("Build sshTunnelPidCommand failed for %s" % (tunnelName))
+         self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
+         self.logger.log(logging.ERROR,getLogMessage("Build sshTunnelPidCommand failed for %s" % (tunnelName)))
 
       return(sshTunnelPidCommand)
 
