@@ -1,10 +1,10 @@
 # @package      hubzero-submit-common
 # @file         UnboundConnection.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -27,8 +27,9 @@
 
 import os.path
 import time
+import logging
 
-from hubzero.submit.LogMessage  import logID as log
+from hubzero.submit.LogMessage  import getLogIDMessage as getLogMessage
 from hubzero.submit.MessageCore import MessageCore
 
 class UnboundConnection:
@@ -43,6 +44,7 @@ class UnboundConnection:
                 listenURIs=[],
                 maximumConnectionPasses=15,
                 submitSSLCA=""):
+      self.logger        = logging.getLogger(__name__)
       self.connection    = None
       self.activeChannel = None
       self.bufferSize    = 1024
@@ -83,24 +85,27 @@ class UnboundConnection:
                   protocol,serverHost,serverPort,serverFile = self.__parseURI(listenURI)
                   if protocol:
                      if   protocol == 'tls':
-                        log("Connecting: protocol='%s', host='%s', port=%d" % (protocol,serverHost,serverPort))
+                        message = "Connecting: protocol='%s', host='%s', port=%d" % (protocol,serverHost,serverPort)
+                        self.logger.log(logging.INFO,getLogMessage(message))
                         self.connection = MessageCore(protocol='tls',bindLabel=listenURI,
                                                       sslCACertPath=submitSSLCA,
                                                       listenerHost=serverHost,listenerPort=serverPort)
                      elif protocol == 'tcp':
-                        log("Connecting: protocol='%s', host='%s', port=%d" % (protocol,serverHost,serverPort))
+                        message = "Connecting: protocol='%s', host='%s', port=%d" % (protocol,serverHost,serverPort)
+                        self.logger.log(logging.INFO,getLogMessage(message))
                         self.connection = MessageCore(protocol='tcp',bindLabel=listenURI,
                                                       sslCACertPath=submitSSLCA,
                                                       listenerHost=serverHost,listenerPort=serverPort)
                      elif protocol == 'file':
-                        log("Connecting: protocol='%s', file='%s'" % (protocol,serverFile))
+                        message = "Connecting: protocol='%s', file='%s'" % (protocol,serverFile)
+                        self.logger.log(logging.INFO,getLogMessage(message))
                         if os.path.exists(serverFile):
                            self.connection = MessageCore(protocol='file',listenerFile=serverFile,
                                                          bindLabel="UD:%s" % (serverFile))
                         else:
-                           log("Connecting file %s missing" % (serverFile))
+                           self.logger.log(logging.ERROR,getLogMessage("Connecting file %s missing" % (serverFile)))
                      else:
-                        log("Unknown protocol: %s" % (protocol))
+                        self.logger.log(logging.ERROR,getLogMessage("Unknown protocol: %s" % (protocol)))
 
                      if self.connection:
                         try:
@@ -122,9 +127,9 @@ class UnboundConnection:
 
                delay = 10.
          else:
-            log("No connections to be configured")
+            self.logger.log(logging.ERROR,getLogMessage("No connections to be configured"))
       else:
-         log("No connections to be configured")
+         self.logger.log(logging.ERROR,getLogMessage("No connections to be configured"))
 
 
    def __parseURI(self,
@@ -146,7 +151,7 @@ class UnboundConnection:
             filePath = filePath.replace('/','',2)
       except:
          protocol = ""
-         log("Improper network specification: %s" % (uri))
+         self.logger.log(logging.ERROR,getLogMessage("Improper network specification: %s" % (uri)))
 
       return(protocol,host,port,filePath)
 
@@ -166,9 +171,9 @@ class UnboundConnection:
             if reply == message:
                valid = True
       except Exception, err:
-         log("ERROR: Connection handshake failed.  Protocol mismatch?")
-         log("handshake(%s): %s" % (message.strip(),reply.strip()))
-         log("err = %s" % (str(err)))
+         self.logger.log(logging.ERROR,getLogMessage("ERROR: Connection handshake failed.  Protocol mismatch?"))
+         self.logger.log(logging.ERROR,getLogMessage("handshake(%s): %s" % (message.strip(),reply.strip())))
+         self.logger.log(logging.ERROR,getLogMessage("err = %s" % (str(err))))
 
       return(valid)
 
@@ -209,8 +214,10 @@ class UnboundConnection:
 
    def sendMessage(self):
       transmittedLength = self.connection.sendMessage(self.activeChannel,self.toBuffer)
-      if transmittedLength > 0:
+      if   transmittedLength > 0:
          self.toBuffer = self.toBuffer[transmittedLength:]
+      elif transmittedLength < 0:
+         self.closeConnection()
 
 
    def receiveMessage(self):
@@ -282,6 +289,6 @@ class UnboundConnection:
    def logPendingMessage(self,
                          logMessage):
       if self.isMessagePending():
-         log("logPendingMessage(%s): %s" % (logMessage,self.toBuffer))
+         self.logger.log(logging.INFO,getLogMessage("logPendingMessage(%s): %s" % (logMessage,self.toBuffer)))
 
 
